<?php
/**
 * Theme admin functions.
 *
 * @package Meridia
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Direct script access denied.' );
}

/**
* Add admin menu
*
* @since 1.0.0
*/
function meridia_theme_admin_menu() {
	add_theme_page(
		__( 'Getting Started', 'meridia' ),
		__( 'Meridia', 'meridia' ),
		'manage_options',
		'getting-started',
		'meridia_admin_page_content',
		30
	);
}
add_action( 'admin_menu', 'meridia_theme_admin_menu' );


/**
* Add admin page content
*
* @since 1.0.0
*/
function meridia_admin_page_content() {
	$theme = wp_get_theme();
	$active_theme_name  = strtolower( preg_replace( '#[^a-zA-Z]#', '', $theme->template ) );

	$urls = array(
		'theme-url'							=> 'https://deothemes.com/wordpress-themes/meridia-minimal-ecommerce-lifestyle-blog-wordpress-theme/',
		'rating-url'						=> 'https://wordpress.org/support/theme/meridia/reviews/?rate=5#new-post',
		'docs' 									=> 'https://demo.deothemes.com/wp_docs/meridia/index.html',	
		'custom-widgets'				=> 'https://demo.deothemes.com/wp_docs/meridia/index.html#custom-widgets',
		'theme-styles'					=> 'https://demo.deothemes.com/wp_docs/meridia/index.html#demo-import',
		'header-types'					=> 'https://demo.deothemes.com/wp_docs/meridia/index.html#header-types',
		'featured-area-types'		=> 'https://demo.deothemes.com/wp_docs/meridia/index.html#featured-area-types',
		'post-layouts'					=> 'https://demo.deothemes.com/wp_docs/meridia/index.html#post-layouts',
		'acf-pro'								=> 'https://demo.deothemes.com/wp_docs/meridia/index.html#acf-pro',
		'gdpr'									=> 'https://demo.deothemes.com/wp_docs/meridia/index.html#gdpr',
		'socials'								=> 'https://demo.deothemes.com/wp_docs/meridia/index.html#social-profiles',		
		'demo-import'						=> 'https://demo.deothemes.com/wp_docs/meridia/index.html#demo-import',
		'woocommerce' 					=> 'https://demo.deothemes.com/wp_docs/meridia/index.html#woocommerce',
	);

	$info = array(
		'theme-styles' => array(
			'title'			=> __( '5 Theme Styles', 'meridia' ),
			'class'			=> 'deo-addon-list-item',
			'title_url' => $urls['theme-styles'],
			'links'			=> array(
				array(
					'link_class'	 => 'deo-learn-more',
					'link_url'		 => $urls['theme-styles'],
					'link_text'    => __( 'Learn More &#187;', 'meridia' ),
					'target_blank' => true
				),
			),
		),
		'custom-widgets' => array(
			'title'			=> __( 'Custom Widgets', 'meridia' ),
			'class'			=> 'deo-addon-list-item',
			'title_url' => $urls['custom-widgets'],
			'links'			=> array(
				array(
					'link_class'	 => 'deo-learn-more',
					'link_url'		 => $urls['custom-widgets'],
					'link_text'    => __( 'Learn More &#187;', 'meridia' ),
					'target_blank' => true
				),
			),
		),
		'header-types' => array(
			'title'			=> __( '4 Header Types', 'meridia' ),
			'class'			=> 'deo-addon-list-item',
			'title_url' => $urls['header-types'],
			'links'			=> array(
				array(
					'link_class'	 => 'deo-learn-more',
					'link_url'		 => $urls['header-types'],
					'link_text'    => __( 'Learn More &#187;', 'meridia' ),
					'target_blank' => true
				),
			),
		),
		'featured-area-types' => array(
			'title'			=> __( '5 Featured Area Types', 'meridia' ),
			'class'			=> 'deo-addon-list-item',
			'title_url' => $urls['featured-area-types'],
			'links'			=> array(
				array(
					'link_class'	 => 'deo-learn-more',
					'link_url'		 => $urls['featured-area-types'],
					'link_text'    => __( 'Learn More &#187;', 'meridia' ),
					'target_blank' => true
				),
			),
		),
		'post-layouts' => array(
			'title'			=> __( '5 Post Layouts', 'meridia' ),
			'class'			=> 'deo-addon-list-item',
			'title_url' => $urls['post-layouts'],
			'links'			=> array(
				array(
					'link_class'	 => 'deo-learn-more',
					'link_url'		 => $urls['post-layouts'],
					'link_text'    => __( 'Learn More &#187;', 'meridia' ),
					'target_blank' => true
				),
			),
		),
		'acf-pro' => array(
			'title'			=> __( 'ACF Pro included (Save $49)', 'meridia' ),
			'class'			=> 'deo-addon-list-item',
			'title_url' => $urls['acf-pro'],
			'links'			=> array(
				array(
					'link_class'	 => 'deo-learn-more',
					'link_url'		 => $urls['acf-pro'],
					'link_text'    => __( 'Learn More &#187;', 'meridia' ),
					'target_blank' => true
				),
			),
		),
		'gdpr' => array(
			'title'			=> __( 'GDPR', 'meridia' ),
			'class'			=> 'deo-addon-list-item',
			'title_url' => $urls['gdpr'],
			'links'			=> array(
				array(
					'link_class'	 => 'deo-learn-more',
					'link_url'		 => $urls['gdpr'],
					'link_text'    => __( 'Learn More &#187;', 'meridia' ),
					'target_blank' => true
				),
			),
		),
		'socials' => array(
			'title'			=> __( 'Social Media', 'meridia' ),
			'class'			=> 'deo-addon-list-item',
			'title_url' => $urls['socials'],
			'links'			=> array(
				array(
					'link_class'	 => 'deo-learn-more',
					'link_url'		 => $urls['socials'],
					'link_text'    => __( 'Learn More &#187;', 'meridia' ),
					'target_blank' => true
				),
			),
		),
		'demo-import' => array(
			'title'			=> __( 'One Click Demo Import', 'meridia' ),
			'class'			=> 'deo-addon-list-item',
			'title_url' => $urls['demo-import'],
			'links'			=> array(
				array(
					'link_class'	 => 'deo-learn-more',
					'link_url'		 => $urls['demo-import'],
					'link_text'    => __( 'Learn More &#187;', 'meridia' ),
					'target_blank' => true
				),
			),
		),
		'woocommerce' => array(
			'title'			=> __( 'WooCommerce', 'meridia' ),
			'class'			=> 'deo-addon-list-item',
			'title_url' => $urls['woocommerce'],
			'links'			=> array(
				array(
					'link_class'	 => 'deo-learn-more',
					'link_url'		 => $urls['woocommerce'],
					'link_text'    => __( 'Learn More &#187;', 'meridia' ),
					'target_blank' => true
				),
			),
		),		
	);
	?>

		<div class="deo-page-header">
			<div class="deo-page-header__container">
				<div class="deo-page-header__branding">
					<a href="<?php echo esc_url( $urls['theme-url'] ); ?>" target="_blank" rel="noopener" >
						<img src="<?php echo esc_url( MERIDIA_THEME_URI . '/assets/admin/img/meridia_logo.png' ); ?>" class="deo-page-header__logo" alt="<?php echo esc_attr__( 'Meridia', 'meridia' ); ?>">
					</a>
					<span class="deo-theme-version"><?php echo esc_html( MERIDIA_THEME_VERSION ); ?></span>
				</div>
				<div class="deo-page-header__tagline">
					<span class="deo-page-header__tagline-text">
						<?php 
							printf( esc_html__( 'Modern Blogging WordPress Theme by %s', 'meridia'  ),
								'<a href="https://deothemes.com" target="_blank" rel="noopener">' . esc_html__( 'DeoThemes', 'meridia' ) . '</a>'
							);
						?>
					</span>					
				</div>				
			</div>
		</div>

		<div class="wrap deo-container">
			<div class="deo-grid">
				<div class="deo-grid-content">
					<div class="deo-body">

						<h1 class="deo-title"><?php esc_html_e( 'Getting Started', 'meridia' ); ?></h1>
						<p class="deo-text">
							<?php					
								echo esc_html__( 'Meridia is now installed and ready to use! Get ready to build something beautiful. We hope you enjoy it! Before you get started, install all the required and recommended plugins, without them theme will lack some customizations.', 'meridia' );					
							?>
						</p>

						<?php
							$wizard_completed = get_option( 'merlin_' . $active_theme_name . '_completed' );

							if ( ! $wizard_completed ) : ?>
								<a href="<?php echo esc_url( admin_url( 'themes.php?page=merlin' ) ); ?>" class="button button-primary button-hero">
									<?php echo esc_html__( 'Run Setup Wizard', 'meridia' ); ?>
								</a>
							<?php endif;
						?>

						<h3><?php echo esc_html__( 'What is next?', 'meridia' ); ?></h3>
						<ol>
							<li><?php printf(
								esc_html__( 'Install and activate all the %1$s', 'meridia' ),
								sprintf(
									'<a href="%s">%s</a>',
									esc_url( admin_url( 'themes.php?page=tgmpa-install-plugins' ) ),
									esc_html__( 'required plugins', 'meridia' )											
								)
							); ?></li>
							<li>
								<?php printf(
								esc_html__( 'Connect your %1$s', 'meridia' ),
								sprintf(
									'<a href="%s">%s</a>',
									( defined( 'SBIVER' ) ) ? esc_url( admin_url( 'admin.php?page=sb-instagram-feed' ) ) : esc_url( admin_url( 'themes.php?page=tgmpa-install-plugins' ) ),
									esc_html__( 'Instagram account', 'meridia' )											
								)
							); ?></li>						
							<li>
								<?php if ( class_exists( 'OCDI_Plugin' ) ) : ?>
									<a href="<?php echo esc_url( admin_url( 'themes.php?page=one-click-demo-import' ) ); ?>">
								<?php else : ?>
									<a href="<?php echo esc_url( admin_url( 'themes.php?page=tgmpa-install-plugins' ) ); ?>">
								<?php endif; ?>
										<?php echo esc_html__( 'Import demo content', 'meridia' ); ?>
									</a>								
							</li>
						</ol>
						
						<h4><?php echo esc_html__( 'Helpful Links', 'meridia' ); ?></h4>
						<ul class="deo-list">
							<li>
								<?php
									/* translators: %1$s: Docs URL. */
									printf(
										esc_html__( 'Check the %1$s for installation and customization guides.', 'meridia' ),
										sprintf(
											'<a href="%s" target="_blank">%s</a>',
											esc_url( $urls['docs'] ),
											esc_html__( 'Documentation', 'meridia' )
										)
									);
								?>
							</li>
							<li>
								<?php
									/* translators: %1$s: Customizer URL. */
									printf(
										esc_html__( 'Go to %1$s to modify the look of your site. (requires active Kirki plugin)', 'meridia' ),
										sprintf(
											'<a href="%s" target="_blank">%s</a>',
											esc_url( admin_url( 'customize.php' ) ),
											esc_html__( 'Customizer', 'meridia' )
										)
									);
								?>
							</li>
							<li>
								<?php
									/* translators: %1$s: Contact URL. */
									printf(
										esc_html__( 'Need help? %1$s We\'re happy to help!', 'meridia' ),
										sprintf(
											'<a href="%s">%s</a>',
											esc_url( admin_url( 'themes.php?page=getting-started-contact' ) ),
											esc_html__( 'Get in touch with us.', 'meridia' )
										)
									);
								?>
							</li>
							<li>
								<?php
									/* translators: %1$s: Rating URL. */
									printf(
										esc_html__( 'Enjoying the theme? %1$s Let us know about your experience.', 'meridia' ),
										sprintf(
											'<a href="%s">%s</a>',
											esc_url( $urls['rating-url'] ),
											esc_html__( 'Rate us.', 'meridia' )
										)
									);
								?>
							</li>
						</ul>

					</div> <!-- .body -->

					<div class="deo-postbox">
						<h2 class="deo-addon-title"><?php echo esc_html__( 'More features with Meridia Pro', 'meridia' ); ?></h2>
						<ul class="deo-addon-list">
							<?php
							foreach ( (array) $info as $addon => $info ) {
								$title_url     = ( isset( $info['title_url'] ) && ! empty( $info['title_url'] ) ) ? 'href="' . esc_url( $info['title_url'] ) . '"' : '';
								$anchor_target = ( isset( $info['title_url'] ) && ! empty( $info['title_url'] ) ) ? "target='_blank' rel='noopener'" : '';

								echo '<li class="' . esc_attr( $info['class'] ) . '">
									<div class="deo-addon-list-item-feature">
										<i class="deo-addon-list-item-icon dashicons dashicons-yes" aria-hidden="true"></i><a class="deo-addon-item-title"' . $title_url . $anchor_target . ' >' . esc_html( $info['title'] ) . '</a>
									</div>
									<div class="deo-addon-link-wrapper">';

									foreach ( $info['links'] as $key => $link ) {
										printf(
											'<a class="%1$s" %2$s %3$s> %4$s </a>',
											esc_attr( $link['link_class'] ),
											isset( $link['link_url'] ) ? 'href="' . esc_url( $link['link_url'] ) . '"' : '',
											( isset( $link['target_blank'] ) && $link['target_blank'] ) ? 'target="_blank" rel="noopener"' : '', // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
											esc_html( $link['link_text'] )
										);
									}

								echo '</div></li>';
							}
							?>
						</ul>
					</div>

				</div> <!-- .content -->
			</div> <!-- .grid -->
		</div>
	<?php
}


/**
* Change theme icon
*
* @since 1.0.0
*/
function meridia_fs_custom_icon() {
  return MERIDIA_THEME_DIR . '/assets/admin/img/theme-icon.jpg';
} 
meridia_fs()->add_filter( 'plugin_icon' , 'meridia_fs_custom_icon' );



/**
* Adds an admin notice upon successful activation.
*/
function meridia_activation_admin_notice() {
	global $current_user;
	global $current_screen;

	// Don't show on Meridia main admin page
	if ( $current_screen->id === 'appearance_page_getting-started' || $current_screen->id === 'toplevel_page_getting-started' ) {
		return;
	}

	if ( is_admin() ) {

		$current_theme = wp_get_theme();
		$welcome_dismissed = get_user_meta( $current_user->ID, 'meridia_wizard_admin_notice' );

		if ( ( $current_theme->get('Name') == "Meridia" || $current_theme->get('Name') == "Meridia Pro" ) && ! $welcome_dismissed ) {
			add_action( 'admin_notices', 'meridia_wizard_admin_notice', 99 );
		}

		wp_enqueue_style( 'meridia-wizard-notice-css', get_template_directory_uri() . '/assets/admin/css/wizard-notice.css' );

	}
}
add_action( 'current_screen', 'meridia_activation_admin_notice' );



/**
* Adds a button to dismiss the notice
*/
function meridia_dismiss_wizard_notice() {
	global $current_user;
	$user_id = $current_user->ID;

	if ( isset( $_GET['meridia_wizard_dismiss'] ) && $_GET['meridia_wizard_dismiss'] == '1' ) {
		add_user_meta( $user_id, 'meridia_wizard_admin_notice', 'true', true );
	}
}
add_action( 'admin_init', 'meridia_dismiss_wizard_notice', 1 );


/**
* Display an admin notice linking to the wizard screen
*/
function meridia_wizard_admin_notice() {
	if ( current_user_can( 'customize' ) ) : ?>
		<div class="notice theme-notice welcome-panel">
			<div class="theme-notice-logo">
				<img src="<?php echo esc_url( MERIDIA_THEME_URI . '/assets/admin/img/meridia_logo.png' ); ?>" alt="<?php esc_attr_e( 'Meridia', 'meridia' ) ?>">
			</div>
			<div class="theme-notice-message wp-theme-fresh">
				<h2><?php esc_html_e( 'Thank you for choosing Meridia!', 'meridia' ); ?></h2>
				<?php if ( class_exists( 'Merlin' ) ) : ?>
					<p class="about-description"><?php esc_html_e( 'Run the Setup Wizard to configure your new theme and begin customizing your site.', 'meridia' ); ?></p>
				<?php else : ?>
					<p class="about-description"><?php esc_html_e( 'Follow the steps to configure your new theme and begin customizing your site.', 'meridia' ); ?></p>
				<?php endif; ?>
			</div>
			<div class="theme-notice-cta">
				<?php if ( class_exists( 'Merlin' ) ) : ?>
					<a href="<?php echo esc_url( admin_url( 'themes.php?page=merlin' ) ); ?>" class="button button-primary button-hero" style="text-decoration: none;"><?php esc_html_e( 'Run Setup Wizard', 'meridia' ); ?></a>
				<?php else : ?>
					<a href="<?php echo esc_url( admin_url( 'themes.php?page=getting-started' ) ); ?>" class="button button-primary button-hero" style="text-decoration: none;"><?php esc_html_e( 'Setup Instructions', 'meridia' ); ?></a>
				<?php endif; ?>
				<a href="<?php echo esc_url( wp_nonce_url( add_query_arg( 'meridia_wizard_dismiss', '1' ) ) ); ?>" class="notice-dismiss" target="_parent"></a>
			</div>
		</div>
	<?php endif;
}